mocks

package
v0.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockMaterializationAdapter added in v0.34.0

type MockMaterializationAdapter struct {
	// contains filtered or unexported fields
}

MockMaterializationAdapter is a mock of MaterializationAdapter interface.

func NewMockMaterializationAdapter added in v0.34.0

func NewMockMaterializationAdapter(ctrl *gomock.Controller) *MockMaterializationAdapter

NewMockMaterializationAdapter creates a new mock instance.

func (*MockMaterializationAdapter) Dematerialize added in v0.34.0

Dematerialize mocks base method.

func (*MockMaterializationAdapter) EXPECT added in v0.34.0

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMaterializationAdapter) Materialize added in v0.34.0

Materialize mocks base method.

func (*MockMaterializationAdapter) ScopeSupport added in v0.34.0

ScopeSupport mocks base method.

func (*MockMaterializationAdapter) SupportedComponents added in v0.34.0

func (m *MockMaterializationAdapter) SupportedComponents() []plugins.ComponentType

SupportedComponents mocks base method.

type MockMaterializationAdapterMockRecorder added in v0.34.0

type MockMaterializationAdapterMockRecorder struct {
	// contains filtered or unexported fields
}

MockMaterializationAdapterMockRecorder is the mock recorder for MockMaterializationAdapter.

func (*MockMaterializationAdapterMockRecorder) Dematerialize added in v0.34.0

func (mr *MockMaterializationAdapterMockRecorder) Dematerialize(ctx, req any) *gomock.Call

Dematerialize indicates an expected call of Dematerialize.

func (*MockMaterializationAdapterMockRecorder) Materialize added in v0.34.0

func (mr *MockMaterializationAdapterMockRecorder) Materialize(ctx, req any) *gomock.Call

Materialize indicates an expected call of Materialize.

func (*MockMaterializationAdapterMockRecorder) ScopeSupport added in v0.34.0

ScopeSupport indicates an expected call of ScopeSupport.

func (*MockMaterializationAdapterMockRecorder) SupportedComponents added in v0.34.0

func (mr *MockMaterializationAdapterMockRecorder) SupportedComponents() *gomock.Call

SupportedComponents indicates an expected call of SupportedComponents.

type MockPluginService

type MockPluginService struct {
	// contains filtered or unexported fields
}

MockPluginService is a mock of PluginService interface.

func NewMockPluginService

func NewMockPluginService(ctrl *gomock.Controller) *MockPluginService

NewMockPluginService creates a new mock instance.

func (*MockPluginService) Build

Build mocks base method.

func (*MockPluginService) DeleteBuild

func (m *MockPluginService) DeleteBuild(ctx context.Context, tag string) error

DeleteBuild mocks base method.

func (*MockPluginService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockPluginService) GetContent

GetContent mocks base method.

func (*MockPluginService) Info added in v0.34.0

Info mocks base method.

func (*MockPluginService) Install added in v0.34.0

Install mocks base method.

func (*MockPluginService) List added in v0.34.0

List mocks base method.

func (*MockPluginService) ListBuilds

func (m *MockPluginService) ListBuilds(ctx context.Context) ([]plugins.LocalBuild, error)

ListBuilds mocks base method.

func (*MockPluginService) Push

Push mocks base method.

func (*MockPluginService) Uninstall added in v0.34.0

Uninstall mocks base method.

func (*MockPluginService) Validate

Validate mocks base method.

type MockPluginServiceMockRecorder

type MockPluginServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockPluginServiceMockRecorder is the mock recorder for MockPluginService.

func (*MockPluginServiceMockRecorder) Build

func (mr *MockPluginServiceMockRecorder) Build(ctx, opts any) *gomock.Call

Build indicates an expected call of Build.

func (*MockPluginServiceMockRecorder) DeleteBuild

func (mr *MockPluginServiceMockRecorder) DeleteBuild(ctx, tag any) *gomock.Call

DeleteBuild indicates an expected call of DeleteBuild.

func (*MockPluginServiceMockRecorder) GetContent

func (mr *MockPluginServiceMockRecorder) GetContent(ctx, opts any) *gomock.Call

GetContent indicates an expected call of GetContent.

func (*MockPluginServiceMockRecorder) Info added in v0.34.0

func (mr *MockPluginServiceMockRecorder) Info(ctx, opts any) *gomock.Call

Info indicates an expected call of Info.

func (*MockPluginServiceMockRecorder) Install added in v0.34.0

func (mr *MockPluginServiceMockRecorder) Install(ctx, opts any) *gomock.Call

Install indicates an expected call of Install.

func (*MockPluginServiceMockRecorder) List added in v0.34.0

func (mr *MockPluginServiceMockRecorder) List(ctx, opts any) *gomock.Call

List indicates an expected call of List.

func (*MockPluginServiceMockRecorder) ListBuilds

func (mr *MockPluginServiceMockRecorder) ListBuilds(ctx any) *gomock.Call

ListBuilds indicates an expected call of ListBuilds.

func (*MockPluginServiceMockRecorder) Push

func (mr *MockPluginServiceMockRecorder) Push(ctx, opts any) *gomock.Call

Push indicates an expected call of Push.

func (*MockPluginServiceMockRecorder) Uninstall added in v0.34.0

func (mr *MockPluginServiceMockRecorder) Uninstall(ctx, opts any) *gomock.Call

Uninstall indicates an expected call of Uninstall.

func (*MockPluginServiceMockRecorder) Validate

func (mr *MockPluginServiceMockRecorder) Validate(ctx, path any) *gomock.Call

Validate indicates an expected call of Validate.

Jump to